%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Technical Note 169
% Parameters for 'Proportional droop control' system
% Copyright imperix ltd, 2024
% dev@imperix.ch
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clearvars -except SIMULINK_MODE variant_generation variant_simulation

%% SYSTEM PARAMETERS
SwitchingFreq = 50e3;           % Switching frequency [Hz]
ControlFreq = SwitchingFreq;    % Control frequency [Hz]
ControlPeriod = 1/ControlFreq;  % Control period [s]
SamplingPhase = 0;            % Sampling phase [-]

Vdc0 = 800;                     % Initial DC voltage [V]
Vg = 230;                       % RMS Grid voltage [V]
Freq = 50;                      % Grid frequency [Hz]
Lg = 0.95e-3;                   % TPI main inductor value [H]
Rg = 54e-3;                     % Series equivalent resistance of Lg [ohm]
Cf = 12.9e-6;                   % Capacitance of the filter [F]

%% GRID CURRENT CONTROLLER PARAMETERS
% Optimum magnitude criterion
K1 = 1/Rg;
T1 = Lg/Rg;
Td1 = (1/2 + 1/2 + 1/2)*ControlPeriod;
Tn1 = T1;
Ti1 = 2*K1*Td1;
Kp_I = Tn1/Ti1;
Ki_I = 1/Ti1;

%% GRID VOLTAGE CONTROLLER PARAMETERS
% Symmetrical optimum criterion
T2 = Cf;
Tdeq = 10*Td1;
a = 2;
Ti2 = a^2*Tdeq;
Kp_V = T2/(a*Tdeq);
Ki_V = Kp_V/Ti2;

%% DROOP CONTROLLER PARAMETERS
% Proportional droop control
P_max=18e3;                     % Maximum active power 
S_max=22e3;                     % Maximum reactive power

w0 = 2*pi*Freq;                 % Active power control droop coefficient m calculation
delta_w_pu=1/100;               % maximum allowed deviation from w0 (1%)
delta_w=delta_w_pu*w0;
m=delta_w/P_max;

delta_V_pu=10/100;              % maximum allowed deviation from Vg (10%)
delta_V=Vg*sqrt(2)*delta_V_pu;  % Reactive power control droop coefficient n calculation
Q_max=sqrt(S_max^2-P_max^2);   
n=delta_V/Q_max;

